from setuptools import setup

setup(
    name='masonite-dashboard',
    packages=[
        'dashboard',
        'dashboard.controllers',
        'dashboard',
    ],
    version='0.1.1',
    install_requires=[
        
    ],
    description='Masonite Dashboard',
    author='Joseph Mancuso',
    author_email='idmann509@gmail.com',
    url='https://github.com/MasoniteFramework/masonite',
    keywords=['python web framework', 'python3'],
    classifiers=[],
    include_package_data=True,
)
